@@ -457,7 +457,7 @@ const char *ssl_cmd_SSLRandomSeed(
     else {
         if (pRS->nSrc == SSL_RSSRC_BUILTIN)
             return "SSLRandomSeed: byte specification not "
-                   "allowd for builtin seed source";
+                   "allowed for builtin seed source";
         pRS->nBytes = atoi(arg3);
         if (pRS->nBytes < 0)
             return "SSLRandomSeed: invalid number of bytes specified";
