@@ -241,11 +241,12 @@ static int ssl_io_suck_read(SSL *ssl, char *buf, int len)
 {
     ap_ctx *actx;
     struct ssl_io_suck_st *ss;
-    request_rec *r;
+    request_rec *r = NULL;
     int rv;
 
     actx = (ap_ctx *)SSL_get_app_data2(ssl);
-    r    = (request_rec *)ap_ctx_get(actx, "ssl::request_rec");
+    if (actx != NULL)
+        r = (request_rec *)ap_ctx_get(actx, "ssl::request_rec");
 
     rv = -1;
     if (r != NULL) {
