@@ -887,6 +887,20 @@ int ssl_hook_Access(request_rec *r)
     }
 #endif /* SSL_EXPERIMENTAL */
 
+#ifndef SSL_EXPERIMENTAL 
+    /* 
+     *  SSL renegotiations in conjunction with HTTP
+     *  requests using the POST method are not supported.
+     */
+    if (renegotiate && r->method_number == M_POST) {
+        ssl_log(r->server, SSL_LOG_ERROR,
+                "SSL Re-negotiation in conjunction with POST method not supported!");
+        ssl_log(r->server, SSL_LOG_INFO,
+                "There is only experimental support which has to be enabled first");
+        return METHOD_NOT_ALLOWED;
+    }
+#endif /* not SSL_EXPERIMENTAL */
+
     /*
      * now do the renegotiation if anything was actually reconfigured
      */
@@ -938,6 +952,9 @@ int ssl_hook_Access(request_rec *r)
                 SSL_set_session_id_context(ssl, (unsigned char *)&(r->main), sizeof(r->main));
             else
                 SSL_set_session_id_context(ssl, (unsigned char *)&r, sizeof(r));
+#ifdef SSL_EXPERIMENTAL
+            ssl_io_suck(r, ssl);
+#endif
             SSL_renegotiate(ssl);
             SSL_do_handshake(ssl);
             if (SSL_get_state(ssl) != SSL_ST_OK) {
@@ -1562,9 +1579,17 @@ int ssl_callback_SSLVerify_CRL(
         /*
          * Check if the current certificate is revoked by this CRL
          */
+#if SSL_LIBRARY_VERSION < 0x00904000
         n = sk_num(X509_CRL_get_REVOKED(crl));
+#else
+        n = sk_X509_REVOKED_num(X509_CRL_get_REVOKED(crl));
+#endif
         for (i = 0; i < n; i++) {
+#if SSL_LIBRARY_VERSION < 0x00904000
             revoked = (X509_REVOKED *)sk_value(X509_CRL_get_REVOKED(crl), i);
+#else
+            revoked = sk_X509_REVOKED_value(X509_CRL_get_REVOKED(crl), i);
+#endif
             if (ASN1_INTEGER_cmp(revoked->serialNumber, X509_get_serialNumber(xs)) == 0) {
 
                 serial = ASN1_INTEGER_get(revoked->serialNumber);
