@@ -336,7 +336,7 @@ BOOL ssl_mutex_sem_acquire(void)
     rc = semop(mc->nMutexSEMID, sb, 2);
 #endif
 #ifdef SSL_HAVE_W32SEM
-    rc = ap_acquire_mutex((mutex *)mc->nMutexSEMID);
+    rc = (ap_acquire_mutex((mutex *)mc->nMutexSEMID) == 0);
 #endif
 #endif
     return rc;
