@@ -475,8 +475,8 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int ask_twice)
                 return (-1);
             }
             len = strlen(buf);
-            if (len < 4)
-                fprintf(stderr, "Apache:mod_ssl:Error: Pass phrase too short (needs to be at least 4 chars).\n");
+            if (len < 1)
+                fprintf(stderr, "Apache:mod_ssl:Error: Pass phrase empty (needs to be at least 1 character).\n");
             else
                 break;
         }
